<?php

/**
 * @file
 * User page callbacks for the custom_search module.
 */

/*
 * Presents links to filter the search results.
 */
function custom_search_preprocess_search_results(&$variables) {
  if ($variables['plugin_id'] == 'node_search') {

    $results_config = Drupal::config('custom_search.results');
    $content_config = Drupal::config('custom_search.content');

    $variables['filter_position'] = $results_config->get('filter.position');

    // Save # of results for collapsing advanced search.
    Drupal::state()->set('custom_search.nb_results', count($variables['results']));

    // Generate the filter.
    if ($variables['filter_position'] != 'disabled') {
      // Get search words (minus type:node_type).
      $path = Drupal::request()->server->all();
      $path = $path['REQUEST_URI'];
      $keys = substr($path, strpos($path, 'search/node') + 12);
      $keys = explode('?', $keys);
      $keys = $keys[0];
      // Get Custom Search authorized types.
      $searchable_node_types = $content_config->get('types');
      $searchable_node_types = array_keys(array_filter($searchable_node_types, 'custom_search_filter_array'));
      if (!count($searchable_node_types)) {
        $searchable_node_types = array_keys(node_type_get_names());
      }
      // Build menu.
      $items = array();
      $items[] = l($content_config->get('selector.any_text'), 'search/node/' . $keys);
      foreach ($searchable_node_types as $node_type) {
        $node_info = node_type_load($node_type);
        // Count # of results per type.
        $nbresults = 0;
        foreach ($variables['results'] as $result) {
          if ($result['type'] == $node_info->name) {
            $nbresults++;
          }
        }
        if ($nbresults) {
          $items[] = l($node_info->name, 'search/node/' . $keys, array('query' => array('f[0]' => 'type:' . $node_type)));
        }
      }
      if (!isset($variables['filter-title'])) {
        $variables['filter-title'] = $results_config->get('filter.label');
      }
      if (count($items) > 2) {
        $variables['filter'] = theme('item_list', array('items' => $items, 'title' => $variables['filter-title']));
      }
    }

    $variables['theme_hook_suggestions'][] = 'custom_search-results';

  }
}

/*
 * Customisation of the results info.
 */
function custom_search_preprocess_search_result(&$variables) {

  $results_config = Drupal::config('custom_search.results');

  $infos = array();
  if ($results_config->get('info.type') && $variables['plugin_id'] == 'node_search') {
    $infos[] = $variables['result']['type'];
  }
  if (isset($variables['info_split'])) {
    foreach ($variables['info_split'] as $key => $info) {
      if ($results_config->get('info.' . $key)) {
        array_push($infos, $info);
      }
    }
  }
  $variables['info'] = implode(' - ', $infos);
  $variables['theme_hook_suggestions'][] = 'custom_search-result';

}
