<?php
/**
 * @file
 * Contains \Drupal\custom_search\Form\CustomSearchResultsSettingsForm.
 */

namespace Drupal\custom_search\Form;

use Drupal\Core\Form\ConfigFormBase;

/**
 * Configure custom search settings for this site.
 */
class CustomSearchResultsSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'custom_search_results_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, array &$form_state) {
    $config = $this->configFactory->get('custom_search.results');

    $form['custom_search_target'] = array(
	    '#type'     => 'select',
	    '#title'    => $this->t('Results page opens in'),
	    '#options'  => array(
	      '_self'   => $this->t('the same window'),
	      '_blank'  => $this->t('a new window'),
	    ),
	    '#default_value'  => $config->get('target'),
	  );
	  
	  $form['languages'] = array(
	    '#type'   => 'details',
	    '#title'  => $this->t('Languages'),
    );
    $form['languages']['custom_search_language'] = array(
      '#type'           => 'select',
      '#title'          => $this->t('Search content from'),
      '#options'        => array(
        'all'             => $this->t('any language'),
        'current'         => $this->t('current language'),
        'current_neutral' => $this->t('current language, not specified, or not applicable'),
      ),
      '#description'    => $this->t('Choose which language will be used to search content.'),
      '#default_value'  => $config->get('language'),
    );

	  $form['search_form'] = array(
	    '#type'   => 'details',
	    '#title'  => $this->t('Search form'),
	  );
	  $form['search_form']['custom_search_results_search'] = array(
	    '#type'           => 'checkbox',
	    '#title'          => $this->t('Display basic search'),
	    '#default_value'  => $config->get('search'),
	  );
	  $form['search_form']['custom_search_results_advanced_search'] = array(
	    '#type'           => 'checkbox',
	    '#title'          => $this->t('Display advanced search'),
	    '#default_value'  => $config->get('advanced.visibility'),
	  );
	  $form['search_form']['advanced'] = array(
	    '#type'         => 'details',
	    '#title'        => $this->t('Advanced search'),
	    '#states' => array(
	      'visible' => array(
	        ':input[name="custom_search_results_advanced_search"]' => array('checked' => TRUE),
	      ),
	    ),
	  );
	  $form['search_form']['advanced']['custom_search_results_advanced_search_collapsible'] = array(
	    '#type'           => 'checkbox',
	    '#title'          => $this->t('Collapsible'),
	    '#default_value'  => $config->get('advanced.collapsible'),
	  );
	  $form['search_form']['advanced']['custom_search_results_advanced_search_collapsed'] = array(
	    '#type'           => 'checkbox',
	    '#title'          => $this->t('Collapsed'),
	    '#default_value'  => $config->get('advanced.collapsed'),
	  );
	  $form['search_form']['advanced']['criteria'] = array(
	    '#type'         => 'details',
	    '#title'        => $this->t('Criteria'),
	    '#description'  => $this->t('Select the criteria to display on the advanced search form.'),
	    '#collapsible'  => TRUE,
	    '#collapsed'    => TRUE,
	  );
	  $form['search_form']['advanced']['criteria']['custom_search_advanced_or_display'] = array(
	    '#type'           => 'checkbox',
	    '#title'          => $this->t('Or'),
	    '#default_value'  => $config->get('advanced.criteria.or'),
	  );
	  $form['search_form']['advanced']['criteria']['custom_search_advanced_phrase_display'] = array(
	    '#type'           => 'checkbox',
	    '#title'          => $this->t('Phrase'),
	    '#default_value'  => $config->get('advanced.criteria.phrase'),
	  );
	  $form['search_form']['advanced']['criteria']['custom_search_advanced_negative_display'] = array(
	    '#type'           => 'checkbox',
	    '#title'          => $this->t('Negative'),
	    '#default_value'  => $config->get('advanced.criteria.negative'),
	  );
	  $options = node_type_get_names();
	  $form['search_form']['advanced']['custom_search_advanced_types'] = array(
	    '#type'           => 'checkboxes',
	    '#title'          => $this->t('Content types'),
	    '#options'        => $options,
	    '#description'    => $this->t('Select the content types to display on the advanced search form.'),
      '#default_value'  => $config->get('advanced.types'),
	  );

	  $form['results'] = array(
	    '#type'         => 'details',
	    '#title'        => $this->t('Results'),
	    '#description'  => $this->t('Select data to display below each result.'),
	  );
	  $form['results']['custom_search_results_info_type'] = array(
	    '#type'           => 'checkbox',
	    '#title'          => $this->t('Content type'),
	    '#default_value'  => $config->get('info.type'),
	  );
	  $form['results']['custom_search_results_info_user'] = array(
	    '#type'           => 'checkbox',
	    '#title'          => $this->t('User'),
	    '#default_value'  => $config->get('info.user'),
	  );
	  $form['results']['custom_search_results_info_date'] = array(
	    '#type'           => 'checkbox',
	    '#title'          => $this->t('Date'),
	    '#default_value'  => $config->get('info.date'),
	  );
	  if (module_exists('comment')) {
	    $form['results']['custom_search_results_info_comment'] = array(
	      '#type'           => 'checkbox',
	      '#title'          => $this->t('Comments'),
	      '#default_value'  => $config->get('info.comment'),
	    );
	  }

	  $form['filter'] = array(
	    '#type'         => 'details',
	    '#title'        => $this->t('Filter'),
	    '#description'  => $this->t('Add links to filter the results by content type.'),
	  );
	  $form['filter']['custom_search_filter'] = array(
	    '#type'           => 'select',
	    '#title'          => $this->t('Position'),
	    '#options'        => array(
	      'disabled'  => $this->t('Disabled'),
	      'above'     => $this->t('Above results'),
	      'below'     => $this->t('Below results'),
	    ),
	    '#default_value'  => $config->get('filter.position'),
	  );
	  $form['filter']['custom_search_filter_label'] = array(
	    '#type'           => 'textfield',
	    '#title'          => $this->t('Label text'),
	    '#default_value'  => $config->get('filter.label'),
	    '#description'    => $this->t('Enter the label text for the list. The default value is "Filter the results".'),
	    '#states' => array(
	      'invisible' => array(
	        ':input[name="custom_search_filter"]' => array('value' => 'disabled'),
	      ),
	    ),
	  );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, array &$form_state) {
    $values = $form_state['values'];

    $config = $this->config('custom_search.results')
      ->set('target', $values['custom_search_target'])
      ->set('language', $values['custom_search_language'])
      ->set('search', $values['custom_search_results_search'])
      ->set('advanced.visibility', $values['custom_search_results_advanced_search'])
      ->set('advanced.collapsible', $values['custom_search_results_advanced_search_collapsible'])
      ->set('advanced.collapsed', $values['custom_search_results_advanced_search_collapsed'])
      ->set('advanced.criteria.or', $values['custom_search_advanced_or_display'])
      ->set('advanced.criteria.phrase', $values['custom_search_advanced_phrase_display'])
      ->set('advanced.criteria.negative', $values['custom_search_advanced_negative_display'])
      ->set('advanced.types', $values['custom_search_advanced_types'])
      ->set('info.type', $values['custom_search_results_info_type'])
      ->set('info.user', $values['custom_search_results_info_user'])
      ->set('info.date', $values['custom_search_results_info_date'])
      ->set('info.comment', $values['custom_search_results_info_comment'])
      ->set('filter.position', $values['custom_search_filter'])
      ->set('filter.label', $values['custom_search_filter_label'])
      ->save();

    parent::submitForm($form, $form_state);

  }

}
